Module assignment_parser

Module assignment_parser 

Parsing functions for VeriPB assignments.

A VeriPB assignment is a list of OPB literals. For instance:

x1 ~x13 x42 ~x21 ~variable

sets variables x1 and x42 to true and x13, x21, and variable to false.

Tokenization is preformed using the AssignmentToken.

Functions

parse_bool_assignment
Parse an assignment from a lexer to an Assignment of BooleanVar. This function returns a new Assignment.
parse_bool_assignment_into
Parse an assignment from a lexer into an existing Assignment of BooleanVar.
parse_bool_assignment_to_raw_vec
Parse an assignment from a lexer to a raw Vec<Lit>.