pub enum CNFToken {
Comment,
ProblemHeader,
Integer(Result<isize, ParseIntError>),
}Expand description
Tokens used in the OPB format as specified by the PB competition 2024.
Variants
Comment
Comment lines.
ProblemHeader
DIMACS CNF problem header identifier.
Integer(Result<isize, ParseIntError>)
Integer used to for number of variables, number of clauses, to identify literals, or to end clause.