Parser for the OPB format as specified by the PB competition 2024.
Tokenization is performed using OPBToken.
Functions
- parse_
opb_ from_ file - Parse an OPB file into
Formulaof constraints and store the names of the variables in aVarNameManager. - parse_
opb_ from_ file_ given_ var_ manager - Parse an OPB file into
Formulaof constraints and store the names of the variables in aVarNameManager. - parse_
opb_ objective - Parse an objective specified in OPB format.
- parse_
single_ constraint - Parse a single OPB constraint.