Module parser

Module parser 

Helper functions for parser that can be reused for new parsers.

Functions

get_lines
Get an iterator over the lines at the file with path filename.
get_reader
Get a buffered reader for the file at the path filename.