parse_substitution

Function parse_substitution 

pub fn parse_substitution(
    lex: &mut Lexer<'_, SubstitutionToken>,
    var_names: &mut VarNameManager,
) -> Result<Substitution, Error>
Parse a substitution in VeriPB format into the Substitution data structure.

The substitution is parsed from a lexer that generates tokens of the substitution. A format of a substitution is a list of mappings. A the domain of the mapping are variables and the range of the mapping is 0, 1, or a literal.