Parsing functions for VeriPB assignments.
A VeriPB assignment is a list of OPB literals. For instance:
ⓘ
x1 ~x13 x42 ~x21 ~variablesets variables x1 and x42 to true and x13, x21, and variable to false.
Tokenization is preformed using the AssignmentToken.
Functions
- parse_
bool_ assignment - Parse an assignment from a lexer to an
AssignmentofBooleanVar. This function returns a newAssignment. - parse_
bool_ assignment_ into - Parse an assignment from a lexer into an existing
AssignmentofBooleanVar. - parse_
bool_ assignment_ to_ raw_ vec - Parse an assignment from a lexer to a raw
Vec<Lit>.