pub enum OPBToken {
Comment,
Integer,
Var,
Negation,
GreaterEqual,
LessEqual,
Equal,
Semicolon,
Minimize,
Maximize,
Label,
}Expand description
Tokens used in the OPB format as specified by the PB competition 2024.
Variants
Comment
Comment lines.
Integer
Integer used for coefficients or degree (right-hand side).
Var
OPB variable.
Negation
Negation symbol for a literal.
GreaterEqual
Greater than or equal comparison for PB constraint.
LessEqual
Less than or equal comparison for PB constraint.
Equal
Equal comparison for PB constraint.
Semicolon
Semicolon which should end a PB constraint.
Minimize
Label to start the objective function that should be minimized.
Maximize
Label to start the objective function that should be maximized. While we support maximization objectives in the OPB file, internally the objective is always minimized.
Label
Constraint labels similar to the ones used in the proof format.