Helper functions for parser that can be reused for new parsers.
Functions
- get_
lines - Get an iterator over the lines at the file with path
filename. - get_
reader - Get a buffered reader for the file at the path
filename.
Helper functions for parser that can be reused for new parsers.
filename.filename.